// const puppeteer = require('puppeteer-core');
// const path = require('path'); 
// import { userAgents } from "./userAgents.js";

function sleep(ms) {
  return new Promise(resolve => setTimeout(resolve, ms));
}

function randomBetween(min, max) {
  return Math.floor(Math.random() * (max - min + 1)) + min;
}

// Shared flow: untuk window & headless
async function fullBrowsingFlow(threadId, actions) {
  // 1. Initial delay
  await sleep(randomBetween(5000, 10000));

  // 2. Initial scroll
  await actions.scroll(threadId, 10, 25, 800, 1500);

  await sleep(randomBetween(5000, 8000));

  // 3. Random 5–10x: klik → jeda → scroll → jeda
  const totalActions = randomBetween(3, 10);
  for (let i = 0; i < totalActions; i++) {
    await actions.click(threadId);
    await sleep(randomBetween(5000, 10000));

    await actions.scroll(threadId, 15, 20, 1000, 1800);
    await sleep(randomBetween(5000, 10000));
  }

  // 4. Final delay
  await sleep(randomBetween(5000, 10000));

  // 5. Final scroll
  await actions.scroll(threadId, 15, 20, 1000, 1800);

  // 6. Final wait
  await sleep(randomBetween(10000, 20000));

  // 7. Mouse movement
  await actions.moveMouse(threadId);
}

// Mode WINDOW
export async function navigateToWindow(url, threadId) {
  const userAgent = userAgents[Math.floor(Math.random() * userAgents.length)];
  await window.electronAPI.startBrowserWindow({ url, userAgent, threadId });

  try {
    await fullBrowsingFlow(threadId, {
      scroll: async (id, min, max, iMin, iMax) => {
        await window.electronAPI.scrollBrowserWindow({
          threadId: id,
          times: randomBetween(min, max),
          interval: randomBetween(iMin, iMax),
        });
      },
      click: async (id) => {
        await window.electronAPI.clickRandomLinkWindow({ threadId: id });
      },
      moveMouse: async (id) => {
        await window.electronAPI.moveMouseRandomWindow({ threadId: id });
      }
    });

    await window.electronAPI.closeBrowserWindow({ threadId });

  } catch (err) {
    console.error(`[Thread ${threadId}] Error during window navigation:`, err);
  }
}

// // Mode VIEW OFF / Headless
// export async function navigateToView(url, threadId, showBrowser = false) {
//   if (showBrowser) {
//     await navigateToWindow(url, threadId);
//     return;
//   }

//   console.log(`[Thread ${threadId}] Simulating headless browsing to ${url}...`);

//   try {
//     await fullBrowsingFlow(threadId, {
//       scroll: async (id, min, max, iMin, iMax) => {
//         const count = randomBetween(min, max);
//         for (let i = 0; i < count; i++) {
//           console.log(`[Thread ${id}] Headless scroll`);
//           await sleep(randomBetween(iMin, iMax));
//         }
//       },
//       click: async (id) => {
//         console.log(`[Thread ${id}] Headless click`);
//       },
//       moveMouse: async (id) => {
//         console.log(`[Thread ${id}] Headless mouse move`);
//       }
//     });

//     console.log(`[Thread ${threadId}] Headless browsing finished.`);

//   } catch (err) {
//     console.error(`[Thread ${threadId}] Error during headless navigation:`, err);
//   }
// }
