function wait(ms) {
  return new Promise(resolve => setTimeout(resolve, ms));
}

async function smartDelay(site) {
  if (site.delayMin && site.delayMax) {
    const delay = Math.floor(Math.random() * (site.delayMax - site.delayMin + 1)) + site.delayMin;
    console.log(`⏳ Delay: ${delay}s`);
    await wait(delay * 1000);
  }
}

async function smartScroll(page, site) {
  if (!site.scroll) return;

  console.log('📜 Starting smart scroll...');
  await new Promise(resolve => setTimeout(resolve, 2000));
  await page.setViewport({ width: 1280, height: 800 });

  await page.evaluate(async () => {
    function wait(ms) {
      return new Promise(resolve => setTimeout(resolve, ms));
    }

    function findScrollableElement() {
      const candidates = [document.scrollingElement || document.documentElement, document.body];
      const customScrollables = Array.from(document.querySelectorAll('*')).filter(el => {
        const style = window.getComputedStyle(el);
        return (style.overflowY === 'auto' || style.overflowY === 'scroll') && el.scrollHeight > el.clientHeight + 100;
      });
      return customScrollables[0] || candidates.find(el => el.scrollHeight > el.clientHeight + 100);
    }

    const scrollTarget = findScrollableElement();
    if (!scrollTarget) return;

    let scrolled = 0;
    const viewHeight = scrollTarget.clientHeight || window.innerHeight;
    const MAX_SCROLL_TIME = 30000;
    const MAX_STEPS = 300;
    const startTime = Date.now();
    let counter = 0;
    let pauseDone = false;

    async function step() {
      const distance = Math.floor(Math.random() * 30) + 20;
      const reverseChance = Math.random();

      if (reverseChance < 0.05 && scrolled > 0) {
        const up = Math.floor(Math.random() * 30) + 20;
        scrollTarget.scrollTop -= up;
        scrolled = Math.max(scrolled - up, 0);
      } else {
        scrollTarget.scrollTop += distance;
        scrolled += distance;
      }

      counter++;

      if (counter % (Math.floor(Math.random() * 5) + 10) === 0) {
        await wait(Math.random() * 2000 + 1000);
      }

      if (!pauseDone && scrolled > scrollTarget.scrollHeight / 2 && Math.random() < 0.3) {
        await wait(Math.random() * 4000 + 3000);
        pauseDone = true;
      }

      await wait(Math.random() * 400 + 100);
    }

    let steps = 0;
    while (scrolled < scrollTarget.scrollHeight - viewHeight - 200 &&
      (Date.now() - startTime) < MAX_SCROLL_TIME &&
      steps < MAX_STEPS) {
      await step();
      steps++;
    }
  });

  console.log('✅ Scroll done');
}

async function smartClickNav(page, site) {
  if (!site.clickNav) return;

  console.log('🔗 Trying smart click navigation...');
  const randomLink = await page.evaluate(() => {
    const domain = location.hostname;
    const anchors = Array.from(document.querySelectorAll('a'));
    const links = anchors.map(a => a.href).filter(href => {
      try {
        return new URL(href).hostname === domain;
      } catch {
        return false;
      }
    });
    if (links.length > 0) {
      return links[Math.floor(Math.random() * links.length)];
    }
    return null;
  });

  if (randomLink) {
    console.log('➡️ Clicking:', randomLink);
    await page.goto(randomLink, { waitUntil: 'networkidle2' });
    await wait(3000);
  } else {
    console.log('❌ No internal link found.');
  }
}

async function smartClickSelector(page, site) {
  if (!site.clickSelector) return;

  console.log('🖱️ Trying click selector:', site.clickSelector);
  try {
    await page.click(site.clickSelector, { delay: Math.random() * 200 + 100 });
    await wait(500);
  } catch (err) {
    console.log('❌ Selector click failed:', site.clickSelector);
  }
}

async function smartSleep(site) {
  if (site.sleepMin && site.sleepMax) {
    const sleep = Math.floor(Math.random() * (site.sleepMax - site.sleepMin + 1)) + site.sleepMin;
    console.log(`😴 Sleep after click: ${sleep}s`);
    await wait(sleep * 1000);
  }
}

  

// async function smartLoop(page, site) {
//   const loopCount = site.loopCount || 1;

//   for (let i = 0; i < loopCount; i++) {
//     console.log(`🔁 Loop ${i + 1}/${loopCount}`);

//     try {
//       const navMode = (site.navigationMode || 'direct').toLowerCase();
//       const searchEngine = (site.searchEngine || 'google').toLowerCase();
//       const keyword = site.keyword || '';
//       const targetDomain = (site.targetDomain || '').toLowerCase().replace(/^www\./, '');

//       if (navMode === 'search') {
//         if (searchEngine === 'google') {
//           console.log(`🔍 Google search: "${keyword}"`);
//           await page.goto('https://www.google.com', { waitUntil: 'domcontentloaded' });
//           await page.waitForSelector('input[name="q"]');
//           await wait(1000);
//           await page.type('input[name="q"]', keyword, { delay: 100 });
//           await page.keyboard.press('Enter');
//           await page.waitForNavigation({ waitUntil: 'networkidle2' });
//         } else if (searchEngine === 'bing') {
//           console.log(`🔍 Bing search: "${keyword}"`);
//           await page.goto('https://www.bing.com', { waitUntil: 'domcontentloaded' });
//           const inputSelector = 'input[name="q"], input[type="search"]';
//           await page.waitForSelector(inputSelector, { timeout: 8000 });
//           await wait(1000);
//           const input = await page.$(inputSelector);
//           if (input) {
//             await input.type(keyword, { delay: 100 });
//             await page.keyboard.press('Enter');
//             await page.waitForNavigation({ waitUntil: 'networkidle2' });
//             await wait(2000);
//           } else {
//             console.warn('❌ Input pencarian Bing tidak ditemukan.');
//             return;
//           }
//         }

//         // Klik berdasarkan domain
//         const resultClicked = await page.evaluate((targetDomain) => {
//           const anchors = Array.from(document.querySelectorAll('a'));
//           const clean = (d) => d.toLowerCase().replace(/^www\./, '');

//           for (const a of anchors) {
//             try {
//               const href = a.href;
//               const url = new URL(href);
//               const linkDomain = clean(url.hostname);

//               if (linkDomain === clean(targetDomain)) {
//                 a.scrollIntoView({ behavior: 'smooth', block: 'center' });
//                 a.click();
//                 return true;
//               }

//               // Penanganan redirect bing (u=...)
//               const u = new URLSearchParams(url.search).get('u');
//               if (u) {
//                 const realUrl = new URL(decodeURIComponent(u));
//                 const realDomain = clean(realUrl.hostname);
//                 if (realDomain === clean(targetDomain)) {
//                   a.scrollIntoView({ behavior: 'smooth', block: 'center' });
//                   a.click();
//                   return true;
//                 }
//               }
//             } catch (_) {}
//           }
//           return false;
//         }, targetDomain);

//         if (!resultClicked) {
//           console.warn('⚠️ Target domain tidak ditemukan di hasil pencarian.');
//           return;
//         }

//         await page.waitForNavigation({ waitUntil: 'networkidle2', timeout: 15000 }).catch(() => {});
//         await wait(3000);
//       } else {
//         // Mode direct
//         await page.goto(site.url, { waitUntil: 'networkidle2' });
//         await wait(3000);
//       }

//       await smartDelay(site);
//       await smartScroll(page, site);
//       await smartDelay(site);
//       await smartClickNav(page, site);
//       await smartSleep(site);
//       await smartClickSelector(page, site);

//       console.log(`✅ Finished loop ${i + 1}`);
//     } catch (err) {
//       console.log(`❌ Error during loop ${i + 1}:`, err.message);
//     }
//   }
// }

async function smartLoop(page, site) {
  const loopCount = site.loopCount || 1;

  for (let i = 0; i < loopCount; i++) {
    console.log(`🔁 Loop ${i + 1}/${loopCount}`);

    try {
      const navMode = (site.navigationMode || 'direct').toLowerCase();
      const searchEngine = (site.searchEngine || 'google').toLowerCase();
      const keyword = site.keyword || '';
      const targetUrl = site.url;
      const targetDomain = (site.targetDomain || '').replace(/^https?:\/\//, '').toLowerCase();

      if (navMode === 'search') {
        if (searchEngine === 'google') {
          console.log(`🔍 Google search: "${keyword}"`);
          if (searchEngine === 'google') {
            console.log(`🔍 Google search: "${keyword}"`);
            await page.goto('https://www.google.com/ncr', { waitUntil: 'domcontentloaded' });
            await wait(3000); 
          
            // Handle consent screen
            try {
              const consentBtn = await page.$('form[action*="consent"] button, [aria-label="Agree to the use of cookies and other data"]');
              if (consentBtn) {
                console.log('🛡️ Detected consent screen, clicking agree...');
                await consentBtn.click();
                await wait(3000); 
              }
            } catch (err) {
              console.log('⚠️ No consent popup found or failed to click it.');
            }
          
            // Wait for search bar to appear
            let inputBox;
            try {
              await page.waitForSelector('input[name="q"], textarea[name="q"]', { timeout: 10000 });
              inputBox = await page.$('input[name="q"], textarea[name="q"]');
            } catch {
              console.warn('❌ Failed to find search input. Possible redirect or block.');
              return;
            }
          
            // Type keyword and search
            if (inputBox) {
              await inputBox.type(keyword, { delay: 100 });
              await page.keyboard.press('Enter');
              await page.waitForNavigation({ waitUntil: 'networkidle2' });
              await wait(3000); 
            } else {
              console.warn('❌ Search input not interactable.');
              return;
            }
          }
          

          
        }

        if (searchEngine === 'bing') {
          console.log(`🔍 Bing search: "${keyword}"`);
          await page.goto('https://www.bing.com', { waitUntil: 'domcontentloaded' });
          const inputSelector = 'input[name="q"], input[type="search"]';
          await page.waitForSelector(inputSelector, { timeout: 8000 });
          await page.type(inputSelector, keyword, { delay: 100 });
          await page.keyboard.press('Enter');
          await page.waitForNavigation({ waitUntil: 'networkidle2' });
        }

        await wait(3000); 

        const found = await page.evaluate((targetDomain) => {
          const anchors = Array.from(document.querySelectorAll('a'));
          const match = anchors.find(a => {
            try {
              return new URL(a.href).hostname.includes(targetDomain);
            } catch (e) {
              return false;
            }
          });

          if (match) {
            match.scrollIntoView({ behavior: 'smooth', block: 'center' });
            window.location.href = match.href;  // navigasi langsung, hindari tab baru
            return true;
          }
          return false;
        }, targetDomain);

        if (!found) {
          console.warn(`❌ Target domain "${targetDomain}" not found in search results`);
          return;
        }

        await page.waitForNavigation({ waitUntil: 'networkidle2', timeout: 15000 }).catch(() => {});
        await wait(3000);
      } else {
        await page.goto(site.url, { waitUntil: 'networkidle2' });
        await wait(3000);
      }

      await smartDelay(site);
      await smartScroll(page, site);
      await smartDelay(site);
      await smartClickNav(page, site);
      await smartSleep(site);
      await smartScroll(page, site);
      await smartClickSelector(page, site);

      console.log(`✅ Finished loop ${i + 1}`);
    } catch (err) {
      console.log(`❌ Error during loop ${i + 1}:`, err.message);
    }
  }
}


module.exports = {
  smartLoop
};
