export default function Table({ data, onEdit, onStartStop, onDelete }) {
  return React.createElement(
    'div',
    { style: tableWrapper },
    React.createElement(
      'table',
      { style: tableStyle },
      React.createElement(
        'thead',
        {},
        React.createElement(
          'tr',
          {},
          ['#', 'URL', 'Mode', 'Visits', 'Status', 'Actions'].map((header) =>
            React.createElement(
              'th',
              { key: header, style: thStyle },
              header
            )
          )
        )
      ),
      React.createElement(
        'tbody',
        {},
        data.map((site, index) =>
          React.createElement(
            'tr',
            { key: site.id, style: trHover },
            [
              React.createElement('td', { style: tdCenter }, index + 1),
              React.createElement('td', { style: tdUrl }, site.url),
              React.createElement('td', { style: tdCenter }, site.mode),
              React.createElement('td', { style: tdCenter }, site.visits),
              React.createElement('td', { style: tdCenter },
                React.createElement('span', {
                  style: {
                    ...badgeStyle,
                    backgroundColor: site.status === 'Active' ? '#28a745' : '#dc3545'
                  }
                }, site.status)
              ),
              React.createElement(
                'td',
                { style: tdCenter },
                React.createElement('div', { style: actionButtonGroup },
                  React.createElement('button', {
                    onClick: () => onEdit(site),
                    style: btnSmall
                  }, 'Edit'),
                  React.createElement('button', {
                    onClick: () => onStartStop(site),
                    style: {
                      ...btnSmall,
                      backgroundColor: site.status === 'Active' ? '#dc3545' : '#28a745'
                    }
                  }, site.status === 'Active' ? 'Stop' : 'Start'),
                  React.createElement('button', {
                    onClick: () => onDelete(site.id),
                    style: delButton
                  }, 'Del')
                )
              )
            ]
          )
        )
      )
    )
  );
}

// === Styles ===
const tableWrapper = {
  overflowX: 'auto',
  marginTop: '5px',
};

const tableStyle = {
  width: '80%',
  minWidth: '780px',
  borderCollapse: 'collapse',
  boxShadow: '0 2px 8px rgba(0,0,0,0.1)',
  borderRadius: '8px',
  overflow: 'hidden',
};

const thStyle = {
  backgroundColor: '#007bff',
  color: '#fff',
  padding: '12px',
  textAlign: 'center',
  fontSize: '14px'
};

const tdCenter = {
  padding: '10px',
  borderBottom: '1px solid #eee',
  textAlign: 'center',
  fontSize: '13px',
  whiteSpace: 'nowrap'
};

const tdUrl = {
  padding: '10px',
  borderBottom: '1px solid #eee',
  textAlign: 'left',
  fontSize: '13px',
  maxWidth: '250px',
  overflow: 'hidden',
  textOverflow: 'ellipsis',
  whiteSpace: 'nowrap'
};

const btnSmall = {
  backgroundColor: '#17a2b8',
  color: 'white',
  padding: '5px 10px',
  border: 'none',
  borderRadius: '5px',
  cursor: 'pointer',
  fontSize: '12px'
};

const delButton = {
  backgroundColor: '#dc3545',
  color: 'white',
  padding: '5px 10px',
  border: 'none',
  borderRadius: '5px',
  cursor: 'pointer',
  fontSize: '12px'
};

const actionButtonGroup = {
  display: 'flex',
  justifyContent: 'center',
  gap: '8px'
};

const trHover = {
  transition: 'background 0.2s',
  cursor: 'pointer'
};

const badgeStyle = {
  display: 'inline-block',
  padding: '5px 10px',
  borderRadius: '20px',
  color: 'white',
  fontSize: '12px',
  minWidth: '60px'
};
