export default function AddSiteModal({ onSave, onCancel }) {
  const [navigationMode, setNavigationMode] = React.useState('Direct');
  const [url, setUrl] = React.useState('');
  const [keyword, setKeyword] = React.useState('');
  const [searchEngine, setSearchEngine] = React.useState('Google');
  const [targetDomain, setTargetDomain] = React.useState('');
  const [delayMin, setDelayMin] = React.useState(2);
  const [delayMax, setDelayMax] = React.useState(5);
  const [sleepMin, setSleepMin] = React.useState(10);
  const [sleepMax, setSleepMax] = React.useState(20);
  const [scroll, setScroll] = React.useState(true);
  const [clickNav, setClickNav] = React.useState(false);
  const [clickSelector, setClickSelector] = React.useState('');
  const [loopSequence, setLoopSequence] = React.useState(1);

  function handleSubmit(e) {
    e.preventDefault();

    if (!url) {
      alert('URL tidak boleh kosong!');
      return;
    }

    if (navigationMode === 'Search' && (!keyword || !targetDomain)) {
      alert('Keyword dan Target Domain wajib diisi untuk Search Mode!');
      return;
    }

    if (delayMin > delayMax || sleepMin > sleepMax) {
      alert('Min value must be less than or equal to Max value!');
      return;
    }

    const data = {
      navigationMode: navigationMode.toLowerCase(),
      url,
      ...(navigationMode === 'Search' && { keyword, searchEngine, targetDomain }),
      delayMin,
      delayMax,
      sleepMin,
      sleepMax,
      scroll,
      clickNav,
      clickSelector,
      loopCount: loopSequence
    };

    onSave(data);
  }

  return React.createElement(
    'form',
    { onSubmit: handleSubmit, style: formStyle },

    React.createElement('h2', { style: titleStyle }, '➕ Add New Site'),

    // Navigation Mode
    labelInput('Navigation Mode:',
      React.createElement('select', { value: navigationMode, onChange: (e) => setNavigationMode(e.target.value), style: inputStyle },
        React.createElement('option', { value: 'Direct' }, 'Direct'),
        React.createElement('option', { value: 'Search' }, 'Search Engine')
      )
    ),

    // URL
    labelInput('Target URL:',
      React.createElement('input', {
        type: 'text', value: url, onChange: (e) => setUrl(e.target.value),
        placeholder: 'https://example.com', style: inputStyle, required: true
      })
    ),

    // Keyword and Search Engine (only if Search Mode)
    navigationMode === 'Search' && React.createElement(React.Fragment, {}, [
      labelInput('Keyword:',
        React.createElement('input', {
          type: 'text',
          value: keyword,
          onChange: (e) => setKeyword(e.target.value),
          placeholder: 'example: buy a cheap laptop',
          style: inputStyle
        })
      ),
      labelInput('Search Engine:',
        React.createElement('select', {
          value: searchEngine,
          onChange: (e) => setSearchEngine(e.target.value),
          style: inputStyle
        },
          React.createElement('option', { value: 'Google' }, 'Google'),
          React.createElement('option', { value: 'Bing' }, 'Bing')
        )
      ),
      labelInput('Target Domain:',
        React.createElement('input', {
          type: 'text',
          value: targetDomain,
          onChange: (e) => setTargetDomain(e.target.value),
          placeholder: 'example.com',
          style: inputStyle
        })
      )
    ]),

    // Delay and Sleep
    rowInputs([
      labelSmall('Delay Min (s):',
        React.createElement('input', {
          type: 'number', value: delayMin, onChange: (e) => setDelayMin(Number(e.target.value)),
          style: inputSmall
        })
      ),
      labelSmall('Delay Max (s):',
        React.createElement('input', {
          type: 'number', value: delayMax, onChange: (e) => setDelayMax(Number(e.target.value)),
          style: inputSmall
        })
      ),
      labelSmall('Sleep Min (s):',
        React.createElement('input', {
          type: 'number', value: sleepMin, onChange: (e) => setSleepMin(Number(e.target.value)),
          style: inputSmall
        })
      ),
      labelSmall('Sleep Max (s):',
        React.createElement('input', {
          type: 'number', value: sleepMax, onChange: (e) => setSleepMax(Number(e.target.value)),
          style: inputSmall
        })
      ),
      labelSmall('Loop Sequence:',
        React.createElement('input', {
          type: 'number', value: loopSequence, onChange: (e) => setLoopSequence(Number(e.target.value)),
          style: inputSmall
        })
      )
    ]),

    rowOptions([
      checkboxOption('Enable Scroll', scroll, setScroll),
      checkboxOption('Enable Click Navigation', clickNav, setClickNav)
    ]),

    labelInput('Click Selector (Optional):',
      React.createElement('input', {
        type: 'text',
        value: clickSelector,
        onChange: (e) => setClickSelector(e.target.value),
        placeholder: '.my-button',
        style: inputStyle
      })
    ),

    React.createElement('div', { style: buttonGroup },
      React.createElement('button', { type: 'submit', style: saveButton }, 'Save'),
      React.createElement('button', { type: 'button', onClick: onCancel, style: cancelButton }, 'Cancel')
    )
  );
}


// === Helper Functions ===
function labelInput(label, input) {
  return React.createElement('div', { style: labelInputStyle },
    React.createElement('label', {}, label),
    input
  );
}

function labelSmall(label, input) {
  return React.createElement('div', { style: labelSmallStyle },
    React.createElement('label', { style: { fontSize: '13px' } }, label),
    input
  );
}

function checkboxOption(label, checked, setChecked) {
  return React.createElement('label', { style: checkboxStyle },
    React.createElement('input', {
      type: 'checkbox',
      checked,
      onChange: (e) => setChecked(e.target.checked),
      style: { marginRight: '5px' }
    }),
    label
  );
}

function rowInputs(children) {
  return React.createElement('div', { style: rowInputStyle }, children);
}

function rowOptions(children) {
  return React.createElement('div', { style: rowOptionStyle }, children);
}

// === Styles ===
const formStyle = { display: 'flex', flexDirection: 'column', gap: '15px', minWidth: '500px', minHeight: '550px', justifyContent: 'space-between' };
const titleStyle = { marginBottom: '10px', textAlign: 'center' };
const labelInputStyle = { display: 'flex', flexDirection: 'column', gap: '5px' };
const labelSmallStyle = { display: 'flex', flexDirection: 'column', alignItems: 'start', gap: '3px' };
const inputStyle = { padding: '10px', fontSize: '16px', borderRadius: '5px', border: '1px solid #ccc' };
const inputSmall = { padding: '8px', width: '100px', fontSize: '14px', borderRadius: '5px', border: '1px solid #ccc' };
const checkboxStyle = { display: 'flex', alignItems: 'center', gap: '5px' };
const rowInputStyle = { display: 'flex', gap: '20px', justifyContent: 'space-between', alignItems: 'center' };
const rowOptionStyle = { display: 'flex', gap: '20px', alignItems: 'center', marginTop: '10px' };
const buttonGroup = { display: 'flex', justifyContent: 'space-between', marginTop: '20px' };
const saveButton = { backgroundColor: '#28a745', color: 'white', padding: '10px 20px', border: 'none', borderRadius: '5px', cursor: 'pointer' };
const cancelButton = { backgroundColor: '#dc3545', color: 'white', padding: '10px 20px', border: 'none', borderRadius: '5px', cursor: 'pointer' };
