export default function UpgradeVIPModal({ onUpgrade, onCancel }) {
  return React.createElement(
    'div',
    { style: { textAlign: 'center' } },

    // Judul dan deskripsi
    React.createElement('h2', {}, 'Upgrade to VIP 🎉'),
    React.createElement('p', {}, 'Enter your VIP code to activate.'),

    // Input kode VIP
    React.createElement('input', {
      id: 'vipCodeInput',
      type: 'text',
      placeholder: 'Enter VIP code',
      style: {
        padding: '10px',
        marginTop: '10px',
        width: '80%',
        borderRadius: '5px',
        border: '1px solid #ccc'
      }
    }),

    // Status pesan
    React.createElement('p', {
      id: 'messageStatus',
      style: { fontSize: '12px', marginTop: '10px', color: 'gray' }
    }),

    // Tombol Submit dan Cancel
    React.createElement(
      'div',
      { style: { marginTop: '20px' } },

      // Tombol Submit
      React.createElement(
        'button',
        {
          onClick: async (event) => {
            const code = document.getElementById('vipCodeInput').value.trim();
            const messageRef = document.getElementById('messageStatus');
            const submitBtn = event.target;

            if (!code) {
              messageRef.textContent = '❌ VIP code cannot be empty!';
              messageRef.style.color = 'red';
              return;
            }

            const clientId = localStorage.getItem('clientId');
            if (!clientId) {
              messageRef.textContent = '❌ clientId tidak ditemukan di localStorage.';
              messageRef.style.color = 'red';
              return;
            }

            submitBtn.disabled = true;
            messageRef.textContent = '⏳ Verifying code...';
            messageRef.style.color = 'gray';

            try {
              const result = await onUpgrade({ code, clientId });

              if (result?.success) {
                messageRef.textContent = '✅ Code applied successfully!';
                messageRef.style.color = 'green';
                document.getElementById('vipCodeInput').value = '';
              } else {
                messageRef.textContent = `❌ ${result?.message || 'Invalid VIP code.'}`;
                messageRef.style.color = 'red';
              }
            } catch (err) {
              console.error(err);
              messageRef.textContent = '❌ Failed to contact server.';
              messageRef.style.color = 'red';
            } finally {
              submitBtn.disabled = false;
            }
          },
          style: { ...vipButton, backgroundColor: '#ffc107' }
        },
        'Submit Code'
      ),

      // Tombol Cancel
      React.createElement(
        'button',
        {
          onClick: onCancel,
          style: { ...vipButton, backgroundColor: '#6c757d', marginLeft: '10px' }
        },
        'Cancel'
      )
    )
  );
}

const vipButton = {
  padding: '10px 20px',
  border: 'none',
  borderRadius: '5px',
  color: 'black',
  fontWeight: 'bold',
  cursor: 'pointer'
};
