import puppeteer from 'puppeteer';

let browser;
let page;

async function startTestTools(urls) {
  try {
    // Cek apakah browser sudah berjalan, jika belum jalankan
    if (!browser) {
      // Memulai browser dalam mode headless atau tidak tergantung status
      browser = await puppeteer.launch({
        headless: false,  // Menonaktifkan headless untuk melihat proses
        args: ['--no-sandbox', '--disable-setuid-sandbox'],
      });
    }

    // Membuka halaman baru di browser
    page = await browser.newPage();

    // Loop untuk mengunjungi setiap URL yang telah disimpan oleh user
    for (const site of urls) {
      await visitSite(site);
    }

    console.log('Test tools completed.');
  } catch (error) {
    console.error('Error while starting test tools:', error);
  }
}

// Fungsi untuk mengunjungi situs dan melakukan navigasi sesuai konfigurasi
// async function visitSite(site) {
//   try {
//     console.log(`Navigating to: ${site.url}`);
    
//     // Menavigasi ke URL yang diberikan oleh pengguna
//     await page.goto(site.url, { waitUntil: 'domcontentloaded' });

//     // Tunggu delay jika diatur oleh client
//     if (site.delay) {
//       console.log(`Waiting for ${site.delay}ms...`);
//       await page.waitForTimeout(site.delay);
//     }

//     // Melakukan scroll ke bawah halaman
//     if (site.scrollToBottom) {
//       await page.evaluate(() => {
//         window.scrollTo(0, document.body.scrollHeight);
//       });
//       console.log('Scrolling to the bottom of the page...');
//     }

//     // Klik selector jika ada (misalnya tombol atau elemen interaktif lainnya)
//     if (site.clickSelector) {
//       await page.click(site.clickSelector);
//       console.log(`Clicking element with selector: ${site.clickSelector}`);
//     }

//     // Klik navigasi jika diatur (untuk mengklik tautan atau tombol yang disebutkan)
//     if (site.clickNav) {
//       await page.click(site.clickNav);
//       console.log(`Clicking navigation link: ${site.clickNav}`);
//     }

//     // Tunggu sleep jika diatur oleh client
//     if (site.sleepTime) {
//       console.log(`Sleeping for ${site.sleepTime}ms...`);
//       await page.waitForTimeout(site.sleepTime);
//     }

//     // Simulasi proses seperti yang diatur (misal: delay dan scroll loop)

//   } catch (error) {
//     console.error(`Error while visiting site ${site.url}:`, error);
//   }
// }

async function visitSite(site) {
  try {
    if (site.mode === 'search') {
      console.log(`Searching for: ${site.keyword}`);

      // Navigasi ke Google
      await page.goto(`https://www.google.com/search?q=${encodeURIComponent(site.keyword)}`, {
        waitUntil: 'domcontentloaded'
      });

      // Tunggu hasil muncul
      await page.waitForTimeout(3000);

      const targetUrl = site.url || '';
      const found = await page.evaluate((targetUrl) => {
        const links = Array.from(document.querySelectorAll('a'));
        const result = links.find(link => link.href.includes(targetUrl));
        if (result) {
          result.click();
          return true;
        }
        return false;
      }, targetUrl);

      if (!found) {
        console.log(`❌ Target not found in search results: ${targetUrl}`);
        return;
      }

      await page.waitForTimeout(3000); // Tunggu halaman tujuan
    } else {
      console.log(`Navigating directly to: ${site.url}`);
      await page.goto(site.url, { waitUntil: 'domcontentloaded' });
    }

    // Sisa interaksi seperti biasa
    if (site.delay) await page.waitForTimeout(site.delay);

    if (site.scrollToBottom) {
      await page.evaluate(() => {
        window.scrollTo(0, document.body.scrollHeight);
      });
    }

    if (site.clickSelector) {
      await page.click(site.clickSelector);
    }

    if (site.clickNav) {
      await page.click(site.clickNav);
    }

    if (site.sleepTime) await page.waitForTimeout(site.sleepTime);

  } catch (error) {
    console.error(`Error while visiting site ${site.url}:`, error);
  }
}

// Fungsi untuk menghentikan browser dan membersihkan sesi
async function stopTestTools() {
  try {
    if (browser) {
      await browser.close();
      browser = null;
      page = null;
      console.log('Test tools stopped and browser closed.');
    }
  } catch (error) {
    console.error('Error while stopping test tools:', error);
  }
}

export { startTestTools, stopTestTools };
