import { userAgents } from "./userAgents.js";
import { actions } from "./actions.js";

function sleep(ms) {
  return new Promise(resolve => setTimeout(resolve, ms));
}

function randomBetween(min, max) {
  return Math.floor(Math.random() * (max - min + 1)) + min;
}

async function fullBrowsingFlow(threadId, actionsHandler) {
  console.log(`[Thread ${threadId}] 🚀 Start browsing flow`);

  await sleep(randomBetween(5000, 10000));

  await actionsHandler.scroll(threadId, 10, 25, 800, 1500);

  await sleep(randomBetween(5000, 8000));

  const totalActions = randomBetween(3, 10);
  for (let i = 0; i < totalActions; i++) {
    await actionsHandler.click(threadId);
    await sleep(randomBetween(5000, 10000));

    await actionsHandler.scroll(threadId, 15, 20, 1000, 1800);
    await sleep(randomBetween(5000, 10000));
  }

  await sleep(randomBetween(5000, 10000));

  await actionsHandler.scroll(threadId, 15, 20, 1000, 1800);

  await sleep(randomBetween(10000, 20000));

  await actionsHandler.moveMouse(threadId);

  console.log(`[Thread ${threadId}] ✅ Finished browsing flow`);
}

export async function navigateToWindow(url, threadId) {
  const userAgent = userAgents[Math.floor(Math.random() * userAgents.length)];
  await window.electronAPI.startBrowserWindow({ url, userAgent, threadId });

  try {
    await fullBrowsingFlow(threadId, {
      scroll: async (id, min, max, iMin, iMax) => {
        await window.electronAPI.scrollBrowserWindow({
          threadId: id,
          times: randomBetween(min, max),
          interval: randomBetween(iMin, iMax),
        });
      },
      click: async (id) => {
        await window.electronAPI.clickRandomLinkWindow({ threadId: id });
      },
      moveMouse: async (id) => {
        await window.electronAPI.moveMouseRandomWindow({ threadId: id });
      }
    });

    await window.electronAPI.closeBrowserWindow({ threadId });

  } catch (err) {
    console.error(`[Thread ${threadId}] ❌ Error during navigation:`, err);
  }
}

export async function navigateToView(url, threadId, showBrowser = false) {
  if (showBrowser) {
    await navigateToWindow(url, threadId);
    return;
  }

  console.log(`[Thread ${threadId}] 🤖 Simulating headless browsing: ${url}`);

  try {
    await fullBrowsingFlow(threadId, {
      scroll: async (id, min, max, iMin, iMax) => {
        const count = randomBetween(min, max);
        for (let i = 0; i < count; i++) {
          console.log(`[Thread ${id}] (headless) smooth scroll`);
          await sleep(randomBetween(iMin, iMax));
        }
      },
      click: async (id) => {
        console.log(`[Thread ${id}] (headless) click`);
      },
      moveMouse: async (id) => {
        console.log(`[Thread ${id}] (headless) move mouse`);
      }
    });

    console.log(`[Thread ${threadId}] ✅ Finished headless browsing`);
  } catch (err) {
    console.error(`[Thread ${threadId}] ❌ Error headless navigation:`, err);
  }
}
